class AnnotationsAPI:
    """
    A class to interact with the Wallabag API for managing annotations on entries.

    ----------
    Attributes

    client : WallabagClient
        The client instance to send API requests.
    """

    def __init__(self, client):
        """
        Initializes the AnnotationsAPI with the WallabagClient.

        ----------
        Parameters

        client : WallabagClient
            The WallabagClient instance to send requests.
        """
        self.client = client

    def get_annotations(self, entry_id):
        """
        Retrieves all annotations for a specific entry.

        ----------
        Parameters

        entry_id : int
            The ID of the entry for which to retrieve annotations.

        ----------
        Returns

        dict
            The list of annotations for the specified entry.
        """
        return self.client.make_request("GET", f"annotations/{entry_id}.json")

    def add_annotation(self, entry_id, text, quote):
        """
        Adds a new annotation to a specific entry.

        ----------
        Parameters

        entry_id : int
            The ID of the entry to annotate.
        text : str
            The text of the annotation.
        quote : str
            The quote related to the annotation.

        ----------
        Returns

        dict
            The details of the newly added annotation.
        """
        data = {"text": text, "quote": quote}
        return self.client.make_request(
            "POST", f"annotations/{entry_id}.json", data=data
        )

    def delete_annotation(self, annotation_id):
        """
        Deletes an annotation from a specific entry.

        ----------
        Parameters

        annotation_id : int
            The ID of the annotation to delete.

        ----------
        Returns

        dict
            The response from the API after deleting the annotation.
        """
        return self.client.make_request("DELETE", f"annotations/{annotation_id}.json")
