class TagsAPI:
    """
    A class to interact with the Wallabag API for managing tags.

    ----------
    Attributes

    client : WallabagClient
        The client instance to send API requests.
    """

    def __init__(self, client):
        """
        Initializes the TagsAPI with the WallabagClient.

        ----------
        Parameters

        client : WallabagClient
            The WallabagClient instance to send requests.
        """
        self.client = client

    def get_tags(self):
        """
        Retrieves all tags associated with entries in Wallabag.

        ----------
        Returns

        dict
            The list of tags.
        """
        return self.client.make_request("GET", "tags.json")

    def add_tag(self, entry_id, tag):
        """
        Adds a tag to a specific entry.

        ----------
        Parameters

        entry_id : int
            The ID of the entry to tag.
        tag : str
            The tag to add to the entry.

        ----------
        Returns

        dict
            The response from the API after adding the tag.
        """
        data = {"entry_id": entry_id, "label": tag}
        return self.client.make_request("POST", "tags.json", data=data)

    def delete_tag(self, tag_id):
        """
        Deletes a tag from an entry.

        ----------
        Parameters

        tag_id : int
            The ID of the tag to delete.

        ----------
        Returns

        dict
            The response from the API after deleting the tag.
        """
        return self.client.make_request("DELETE", f"tags/{tag_id}.json")
